@@ -8,29 +8,52 @@ import shlex
 import dbus
 import conic
 
-import controller as fMMSController
-
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
 
+import controller as fMMSController
+
 magic = 0xacdcacdc
 
 CONNMODE_UGLYHACK = 1                                                          
 CONNMODE_ICDSWITCH = 2                                                         
 CONNMODE_FORCESWITCH = 3                                                       
 CONNMODE_NULL = 10
+ROAMMODE_IGNORE = 2
 
 class MasterConnector:
 	""" handles setting up and (might) take down connection(s) """
 
-	def __init__(self):
-		self.cont = fMMSController.fMMS_controller()
+	def __init__(self, controller=0):
+		if controller == 0:
+			self.cont = fMMSController.fMMS_controller()
+		else:
+			self.cont = controller
 		self.config = self.cont.config
 		self._apn = self.config.get_apn()
 		self._apn_nicename = self.config.get_apn_nicename()
 		self.lock = fMMSController.Locker(self.config.get_lockfile())
 	
 	def connect(self, location="0"):
+		# first check roaming status
+		bus = dbus.SystemBus()
+		phoneobj = bus.get_object('com.nokia.phone.net', '/com/nokia/phone/net')
+		phoneif = dbus.Interface(phoneobj, 'Phone.Net')
+		statusarr = phoneif.get_registration_status()[0]
+		if (self.config.get_roammode() == ROAMMODE_IGNORE) and statusarr != 0:
+			if self.cont.ui:
+				if not self.cont.continue_download_roaming():
+					log.info("user declined to download while roaming")
+					raise Exception('User is roaming, not downloading')
+					return
+				else:
+					log.info("user accepted to download while roaming")
+			else:
+				log.info("not in home network, not downloading..")
+				self.connector = None
+				raise Exception('User is roaming, not downloading')
+				#return
+				
 	
 		# this is to make sure only one process has passed connect() at a time
 		loop = 0
@@ -46,7 +69,8 @@ class MasterConnector:
 					log.info("probable deadlock, kill me please!")
 				if loop > 30:
 					log.info("time to die. bye!")
-					raise Exception('Timeout while waiting for lock')
+					#raise Exception('Timeout while waiting for lock')
+					return
 	
 		if (self.config.get_connmode() == CONNMODE_UGLYHACK):
 			log.info("RUNNING IN UGLYHACK MODE")
