@@ -224,7 +224,7 @@ class fMMS_controller():
 		""" decodes and saves the binary mms"""
 		# Decode the specified file
 		# This also creates all the parts as files in path
-		log.info("decode_binary_mms running")
+		log.info("decode_binary_mms running: %s", str(path))
 		try:
 			message = MMSMessage.fromFile(path + "/message")
 		except Exception, e:
@@ -282,10 +282,13 @@ class fMMS_controller():
 		from wappushhandler import PushHandler
 		p = PushHandler()
 		path = p._get_mms_message(url, trans_id, self)
-		log.info("decoding mms... %s", trans_id)
+		log.info("path: %s", path)
+		print trans_id
+		os.system("if [ ! -f /home/user/.fmms/mms/" + trans_id + "/message.bak ]; then cp /home/user/.fmms/mms/" + trans_id + "/message /home/user/.fmms/mms/" + trans_id + "/message.bak; fi")
 		message = self.decode_binary_mms(path)
+		os.system("if [ -f /home/user/.fmms/mms/" + trans_id + "/message.bak ]; then diff /home/user/.fmms/mms/" + trans_id + "/message /home/user/.fmms/mms/" + trans_id + "/message.bak; if [ \"$?\" == \"0\" ]; then rm /home/user/.fmms/mms/" + trans_id + "/message.bak; fi; fi")
 		log.info("storing mms...%s", trans_id)
-		mmsid = self.store_mms_message(pushid, message)
+		mmsid = self.store_mms_message(pushid, message, transactionId=trans_id)
 		
 	def get_mms_attachments(self, transactionid, allFiles=False):
 		return self.store.get_mms_attachments(transactionid, allFiles)
